# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/christmas_basket/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\ChristmasBasket\\": "packages/litecms/christmas_basket/src",
            "Litecms\\ChristmasBasket\\Seeders\\": "packages/litecms/christmas_basket/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\ChristmasBasket\Providers\ChristmasBasketServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'ChristmasBasket'  => Litecms\ChristmasBasket\Facades\ChristmasBasket::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\ChristmasBasket\\Seeders\\ChristmasBasketTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\ChristmasBasket\Providers\ChristmasBasketServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\ChristmasBasket\Providers\ChristmasBasketServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\ChristmasBasket\Providers\ChristmasBasketServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/christmas_basket/{modulename}

**User**

    http://path-to-route-folder/user/christmas_basket/{modulename}

**Public**

    http://path-to-route-folder/christmas_baskets


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/christmas_basket/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/christmas_basket/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/christmas_basket/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/christmas_basket/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/christmas_basket/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/christmas_basket/{modulename}/{slug}
    METHOD: GET