<?php

namespace Litecms\ChristmasBasket\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Repository\Filter\RequestFilter;
use Litecms\ChristmasBasket\Forms\ChristmasCatalog as ChristmasCatalogForm;
use Litecms\ChristmasBasket\Http\Requests\ChristmasCatalogRequest;
use Litecms\ChristmasBasket\Interfaces\ChristmasCatalogRepositoryInterface;
use Litecms\ChristmasBasket\Repositories\Eloquent\Filters\ChristmasCatalogResourceFilter;
use Litecms\ChristmasBasket\Repositories\Eloquent\Presenters\ChristmasCatalogListPresenter;

/**
 * Resource controller class for christmas_catalog.
 */
class ChristmasCatalogResourceController extends BaseController
{

    /**
     * Initialize christmas_catalog resource controller.
     *
     *
     * @return null
     */
    public function __construct(ChristmasCatalogRepositoryInterface $christmas_catalog)
    {
        parent::__construct();
        $this->form = ChristmasCatalogForm::setAttributes()->toArray();
        $this->modules = $this->modules(config('litecms.christmas_basket.modules'), 'christmas_basket', guard_url('christmas_basket'));
        $this->repository = $christmas_catalog;
    }

    /**
     * Display a list of christmas_catalog.
     *
     * @return Response
     */
    public function index(ChristmasCatalogRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(ChristmasCatalogResourceFilter::class)
            ->setPresenter(ChristmasCatalogListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('christmas_basket::christmas_catalog.names'))
            ->view('christmas_basket::christmas_catalog.index')
            ->data(compact('data', 'meta', 'links', 'modules', 'form'))
            ->output();
    }

    /**
     * Display christmas_catalog.
     *
     * @param Request $request
     * @param Model   $christmas_catalog
     *
     * @return Response
     */
    public function show(ChristmasCatalogRequest $request, ChristmasCatalogRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('christmas_basket::christmas_catalog.name'))
            ->data(compact('data', 'form', 'modules', 'form'))
            ->view('christmas_basket::christmas_catalog.show')
            ->output();
    }

    /**
     * Show the form for creating a new christmas_catalog.
     *
     * @param Request $request
     *x
     * @return Response
     */
    public function create(ChristmasCatalogRequest $request, ChristmasCatalogRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('christmas_basket::christmas_catalog.name'))
            ->view('christmas_basket::christmas_catalog.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Create new christmas_catalog.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ChristmasCatalogRequest $request, ChristmasCatalogRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $repository->create($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.created', ['Module' => trans('christmas_basket::christmas_catalog.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('christmas_basket/christmas_catalog/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/christmas_basket/christmas_catalog'))
                ->redirect();
        }

    }

    /**
     * Show christmas_catalog for editing.
     *
     * @param Request $request
     * @param Model   $christmas_catalog
     *
     * @return Response
     */
    public function edit(ChristmasCatalogRequest $request, ChristmasCatalogRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('christmas_basket::christmas_catalog.name'))
            ->view('christmas_basket::christmas_catalog.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Update the christmas_catalog.
     *
     * @param Request $request
     * @param Model   $christmas_catalog
     *
     * @return Response
     */
    public function update(ChristmasCatalogRequest $request, ChristmasCatalogRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $repository->update($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('christmas_basket::christmas_catalog.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('christmas_basket/christmas_catalog/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('christmas_basket/christmas_catalog/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the christmas_catalog.
     *
     * @param Model   $christmas_catalog
     *
     * @return Response
     */
    public function destroy(ChristmasCatalogRequest $request, ChristmasCatalogRepositoryInterface $repository)
    {
        try {
            $repository->delete();
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('christmas_basket::christmas_catalog.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('christmas_basket/christmas_catalog/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('christmas_basket/christmas_catalog/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }
}
