<?php

namespace Litecms\ChristmasBasket\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\ChristmasBasket\Models\ChristmasBasket;

class ChristmasBasketPolicy
{

    /**
     * Determine if the given user can view the christmas_basket.
     *
     * @param UserPolicyInterface $authUser
     * @param ChristmasBasket $christmas_basket
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, ChristmasBasket $christmas_basket)
    {
        if ($authUser->canDo('christmas_basket.christmas_basket.view') && $authUser->isAdmin()) {
            return true;
        }

        return $christmas_basket->user_id == user_id() && $christmas_basket->user_type == user_type();
    }

    /**
     * Determine if the given user can create a christmas_basket.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('christmas_basket.christmas_basket.create');
    }

    /**
     * Determine if the given user can update the given christmas_basket.
     *
     * @param UserPolicyInterface $authUser
     * @param ChristmasBasket $christmas_basket
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, ChristmasBasket $christmas_basket)
    {
        if ($authUser->canDo('christmas_basket.christmas_basket.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $christmas_basket->user_id == user_id() && $christmas_basket->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given christmas_basket.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, ChristmasBasket $christmas_basket)
    {
        return $christmas_basket->user_id == user_id() && $christmas_basket->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given christmas_basket.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, ChristmasBasket $christmas_basket)
    {
        if ($authUser->canDo('christmas_basket.christmas_basket.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given christmas_basket.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, ChristmasBasket $christmas_basket)
    {
        if ($authUser->canDo('christmas_basket.christmas_basket.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
