<?php

namespace Litecms\ChristmasBasket\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\ChristmasBasket\Models\ChristmasCatalog;

class ChristmasCatalogPolicy
{

    /**
     * Determine if the given user can view the christmas_catalog.
     *
     * @param UserPolicyInterface $authUser
     * @param ChristmasCatalog $christmas_catalog
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, ChristmasCatalog $christmas_catalog)
    {
        if ($authUser->canDo('christmas_basket.christmas_catalog.view') && $authUser->isAdmin()) {
            return true;
        }

        return $christmas_catalog->user_id == user_id() && $christmas_catalog->user_type == user_type();
    }

    /**
     * Determine if the given user can create a christmas_catalog.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('christmas_basket.christmas_catalog.create');
    }

    /**
     * Determine if the given user can update the given christmas_catalog.
     *
     * @param UserPolicyInterface $authUser
     * @param ChristmasCatalog $christmas_catalog
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, ChristmasCatalog $christmas_catalog)
    {
        if ($authUser->canDo('christmas_basket.christmas_catalog.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $christmas_catalog->user_id == user_id() && $christmas_catalog->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given christmas_catalog.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, ChristmasCatalog $christmas_catalog)
    {
        return $christmas_catalog->user_id == user_id() && $christmas_catalog->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given christmas_catalog.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, ChristmasCatalog $christmas_catalog)
    {
        if ($authUser->canDo('christmas_basket.christmas_catalog.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given christmas_catalog.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, ChristmasCatalog $christmas_catalog)
    {
        if ($authUser->canDo('christmas_basket.christmas_catalog.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
