<?php

namespace Litecms\ChristmasBasket\Providers;

use Illuminate\Support\ServiceProvider;
use Litecms\ChristmasBasket\ChristmasBaskets;

class ChristmasBasketServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'christmas_basket');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'christmas_basket');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Litecms\ChristmasBasket\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\ChristmasBasket\Providers\RouteServiceProvider::class);
        // $this->app->register(\Litecms\ChristmasBasket\Providers\EventServiceProvider::class);
        // $this->app->register(\Litecms\ChristmasBasket\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litecms.christmas_basket', function($app)
        {
            return $this->app->make(ChristmasBaskets::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind ChristmasCatalog to repository
        $this->app->bind(
            'Litecms\ChristmasBasket\Interfaces\ChristmasCatalogRepositoryInterface',
            \Litecms\ChristmasBasket\Repositories\Eloquent\ChristmasCatalogRepository::class
        );        // Bind ChristmasBasket to repository
        $this->app->bind(
            'Litecms\ChristmasBasket\Interfaces\ChristmasBasketRepositoryInterface',
            \Litecms\ChristmasBasket\Repositories\Eloquent\ChristmasBasketRepository::class
        );
    }


    /**
     * Merges user's and christmas_basket's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.christmas_basket'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Litecms\ChristmasBasket\Commands\ChristmasBasket::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.christmas_basket'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/christmas_basket.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/christmas_basket')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/christmas_basket')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
