<?php

namespace Litecms\ChristmasBasket\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litecms\ChristmasBasket\Models\ChristmasBasket;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litecms\ChristmasBasket\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/christmas_basket/christmas_catalog/*')) {
            Route::bind('christmas_catalog', function ($christmas_catalog) {
                $christmas_catalogRepo = $this->app->make('Litecms\ChristmasBasket\Interfaces\ChristmasCatalogRepositoryInterface');
                return $christmas_catalogRepo->findorNew($christmas_catalog);
            });
        }
        if (Request::is('*/christmas_basket/christmas_basket/*')) {
            Route::bind('christmas_basket', function ($christmas_basket) {
                $christmas_basketRepo = $this->app->make('Litecms\ChristmasBasket\Interfaces\ChristmasBasketRepositoryInterface');
                return $christmas_basketRepo->findorNew($christmas_basket);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
